--- sslutils.c.orig	2010-11-24 14:07:54.000000000 +0100
+++ sslutils.c	2010-11-24 14:11:03.000000000 +0100
@@ -97,6 +97,15 @@
 int np_net_ssl_check_cert(int days_till_exp){
 #  ifdef USE_OPENSSL
 	X509 *certificate=NULL;
+	
+	X509_NAME *subj=NULL;
+	int nentries,j;
+	char cn[128] = "?";
+	
+	static const char gcc_shutup[]="%x %X - %a %b %Y";
+	time_t notafter;
+
+	
 	ASN1_STRING *tm;
 	int offset;
 	struct tm stamp;
@@ -110,6 +119,47 @@
 		return STATE_CRITICAL;
 	}
 
+	// X509 subject code took from courrier-mta projet (libcouriertls.c)
+	subj=X509_get_subject_name(certificate);
+
+	if(! subj){
+		printf ("%s\n",_("CRITICAL - Cannot retrieve certificate subject."));
+		return STATE_CRITICAL;
+	}
+
+	nentries=X509_NAME_entry_count(subj);
+	for (j=0; j<nentries; j++)
+	{
+		const char *obj_name;
+		X509_NAME_ENTRY *e;
+		ASN1_OBJECT *o;
+		ASN1_STRING *d;
+
+		int dlen;
+		unsigned char *ddata;
+
+		e=X509_NAME_get_entry(subj, j);
+		if (!e)
+				continue;
+
+		o=X509_NAME_ENTRY_get_object(e);
+		d=X509_NAME_ENTRY_get_data(e);
+
+		if (!o || !d)
+				continue;
+
+		obj_name=OBJ_nid2sn(OBJ_obj2nid(o));
+
+		dlen=ASN1_STRING_length(d);
+		ddata=ASN1_STRING_data(d);
+		
+		if (!strcmp (obj_name, "CN"))
+		{
+			strncpy (cn,ddata,127);
+		}
+		
+	}
+
 	/* Retrieve timestamp of certificate */
 	tm = X509_get_notAfter (certificate);
 
@@ -155,17 +205,17 @@
 		 stamp.tm_mday, stamp.tm_year + 1900, stamp.tm_hour, stamp.tm_min);
 
 	if (days_left > 0 && days_left <= days_till_exp) {
-		printf (_("WARNING - Certificate expires in %d day(s) (%s).\n"), days_left, timestamp);
+		printf (_("WARNING - Certificate '%s' expires in %d day(s) (%s).\n"), cn, days_left, timestamp);
 		return STATE_WARNING;
 	} else if (time_left < 0) {
-		printf (_("CRITICAL - Certificate expired on %s.\n"), timestamp);
+		printf (_("CRITICAL - Certificate '%s' expired on %s.\n"), cn, timestamp);
 		return STATE_CRITICAL;
 	} else if (days_left == 0) {
-		printf (_("WARNING - Certificate expires today (%s).\n"), timestamp);
+		printf (_("WARNING - Certificate '%s' expires today (%s).\n"), cn, timestamp);
 		return STATE_WARNING;
 	}
 
-	printf (_("OK - Certificate will expire on %s.\n"), timestamp);
+	printf (_("OK - Certificate '%s' will expire on %s.\n"), cn, timestamp);
 	X509_free (certificate);
 	return STATE_OK;
 #  else /* ifndef USE_OPENSSL */
